========
Astro Pi
========

The Astro Pi software is now called Sense HAT. For information on installing the new software and for comprehensive documentation see `pythonhosted.org/sense-hat`_


.. _pythonhosted.org/sense-hat: http://pythonhosted.org/sense-hat/
